@@ -1,4 +1,4 @@
-// Copyright (C) 2013 - 2017  Metrum Research Group, LLC
+// Copyright (C) 2013 - 2019  Metrum Research Group, LLC
 //
 // This file is part of mrgsolve.
 //
@@ -107,6 +107,7 @@ public:
   void unarm() {Armed=false;}
   
   void phantom_rec() {Output=false; Fromdata=false;}
+  bool is_phantom() {return !Output && !Fromdata;}
   
 protected:
   
@@ -128,6 +129,7 @@ protected:
 
 
 bool CompByTimePosRec(const rec_ptr& a, const rec_ptr& b);
+bool CompEqual(const reclist& a, double time, unsigned int evid, int cmt);
 
 /** 
  * @brief Functor for sorting data records in <code>reclist</code>. 
