@@ -1,4 +1,4 @@
-// Copyright (C) 2013 - 2017  Metrum Research Group, LLC
+// Copyright (C) 2013 - 2019  Metrum Research Group, LLC
 //
 // This file is part of mrgsolve.
 //
@@ -24,9 +24,9 @@
 #define ODEPROBLEM_H
 #include <math.h>
 #include <vector>
+#include "RcppInclude.h"
 #include "odepack_dlsoda.h"
 #include "mrgsolv.h"
-#include "RcppInclude.h"
 #include "datarecord.h"
 
 // 
@@ -36,29 +36,6 @@
 
 class odeproblem;
 
-struct databox {
-  dvec ETA; ///< vector of ETA values
-  dvec EPS; ///< vector of EPS values
-  unsigned int newind; ///< new individual flag
-  double time; ///< current simulation time
-  int evid;  ///< event ID flag
-  unsigned short int SYSTEMOFF; ///< flag to stop advancing system for current ID
-  double id;  ///< current ID
-  double amt; ///< current dosing amount value
-  short int cmt; ///< current compartment value
-  int nid; ///< number of IDs in the data set
-  int idn; ///< current ID number
-  int nrow; ///< number of rows in output data set
-  int rown; ///< current output row number
-  bool CFONSTOP; ///< carry forward on stop indicator
-  void* envir; ///< model environment
-  void stop() {SYSTEMOFF=9;}
-  void stop_id() {SYSTEMOFF=1;}
-  void stop_id_cf(){SYSTEMOFF=2;}
-  std::vector<shuttle> recs;
-  
-};
-
 //! vector of <code>datarecord</code> objects for one <code>ID</code>
 typedef std::vector<rec_ptr> reclist;
 
@@ -78,9 +55,7 @@ typedef void (*deriv_func)(MRGSOLVE_ODE_SIGNATURE);
 typedef void (*config_func)(MRGSOLVE_CONFIG_SIGNATURE);
 
 //! function to hand off to <code>DLSODA</code>
-typedef void main_deriv_func(int* neq, double* t,
-                             double* y,double* ydot,
-                             odeproblem* prob);
+typedef void main_deriv_func(int* neq, double* t,double* y,double* ydot,odeproblem* prob);
 
 #define MRGSOLVE_GET_PRED_CL  (pred[0]) ///< map CL to pred position 0 for <code>$PKMODEL</code>
 #define MRGSOLVE_GET_PRED_VC  (pred[1]) ///< map VC to pred position 1 for <code>$PKMODEL</code>
@@ -106,9 +81,7 @@ void dosimeps(void*);
 class odeproblem : public odepack_dlsoda {
 
 public:
-  odeproblem(Rcpp::NumericVector param,
-             Rcpp::NumericVector init,
-             Rcpp::List funs,
+  odeproblem(Rcpp::NumericVector param,Rcpp::NumericVector init, Rcpp::List funs,
              int n_capture_);
   
   virtual ~odeproblem();
@@ -160,11 +133,6 @@ public:
   void dur(unsigned int pos, double value) {D[pos] = value;}
   double dur(unsigned int pos){return D[pos];}
   
-  void fbio(unsigned int pos, double value) {F.at(pos) = value;}
-  double fbio(unsigned int pos) {return F.at(pos);}
-  
-  double alag(int cmt){return Alag.at(cmt);}
-  
   void reset_newid(const double id_);
   
   void eta(int pos, double value) {d.ETA[pos] = value;}
@@ -176,6 +144,10 @@ public:
   
   int is_on(unsigned int eq_n){return On[eq_n];}
   
+  void fbio(unsigned int pos, double value) {F.at(pos) = value;}
+  double fbio(unsigned int pos);
+  double alag(int cmt);
+
   void time(double time_){d.time = time_;}
   void newind(unsigned int newind_){d.newind = newind_;}
   unsigned int newind(){return d.newind;}
@@ -199,37 +171,37 @@ public:
   void copy_parin(const Rcpp::List& parin);
   void copy_funs(const Rcpp::List& funs);
   
-  bool any_mtime() {return d.recs.size() > 0;}
-  std::vector<shuttle> mtimes(){return d.recs;}
-  void clear_mtime(){d.recs.clear();}
+  bool any_mtime() {return d.mevector.size() > 0;}
+  std::vector<mrgsolve::evdata> mtimes(){return d.mevector;}
+  void clear_mtime(){d.mevector.clear();}
   
 protected:
   
   double* Param; ///< model parameters
-  dvec R0; ///< acutal current infusion rate
+  std::vector<double> R0; ///< acutal current infusion rate
   std::vector<unsigned int> infusion_count; ///< number of active infusions
-  dvec R; ///< receive user input for infusion rate
-  dvec D; ///< receive user input for infusion duration
-  dvec Init_value; ///< initial conditions
-  dvec Init_dummy; ///< initial conditions for user input
-  dvec F; ///< bioavability
-  dvec Alag; ///< dosing lag time
+  std::vector<double> R; ///< receive user input for infusion rate
+  std::vector<double> D; ///< receive user input for infusion duration
+  std::vector<double> Init_value; ///< initial conditions
+  std::vector<double> Init_dummy; ///< initial conditions for user input
+  std::vector<double> F; ///< bioavability
+  std::vector<double> Alag; ///< dosing lag time
 
   std::vector<int> On; ///< compartment on/off indicator
   databox d; ///< various data passed to model functions
   
   int Advan;  ///< simulation mode: 1/2/3/4 (PK models) or 13 (odes)
-  dvec a;     ///< used for advan 1/2/3/4 calculations
-  dvec alpha; ///< used for advan 1/2/3/4 calculation
+  std::vector<double> a;     ///< used for advan 1/2/3/4 calculations
+  std::vector<double> alpha; ///< used for advan 1/2/3/4 calculation
   
-  resim simeta;  ///< functor for resimulating etas
-  resim simeps; ///< functor for resimulating epsilons
+  mrgsolve::resim simeta;  ///< functor for resimulating etas
+  mrgsolve::resim simeps; ///< functor for resimulating epsilons
 
   arma::mat Omega; ///< variance/covariance matrix for between-subject variability
   arma::mat Sigma; ///< variance/covariance matrix for within-subject variability
     
-  dvec pred; ///< brings clearances, volumes, and kas for advan 1/2/3/4 calculations
-  dvec Capture; ///< captured data items
+  std::vector<double> pred; ///< brings clearances, volumes, and & for advan 1/2/3/4
+  std::vector<double> Capture; ///< captured data items
   
   deriv_func Derivs; ///< <code>$ODE</code> function
   init_func Inits; ///< <code>$MAIN</code> function
@@ -253,8 +225,8 @@ double PolyExp(const double& x,
                const double& xinf,
                const double& tau,
                const bool ss,
-               const dvec& a,
-               const dvec& alpha,
+               const std::vector<double>& a,
+               const std::vector<double>& alpha,
                const int n);
 
 Rcpp::List TOUCH_FUNS(const Rcpp::NumericVector& lparam, 
